@@ -1,18 +1,10 @@
-supported.versions <- c("1.0.3", "1.0.2")
-
 .onLoad <- function(lib, pkg)
 {
-    for (i in seq(along=supported.versions)) {
-        ## FIXME - We should user SOFTWARE\JAGS\version in future
-        key <- paste("SOFTWARE\\JAGS-", supported.versions[i], sep="")
-        regkey <- try(readRegistry(key, hive = "HLM", maxdepth = 1),
-                      silent = TRUE)
-        if(!inherits(regkey, "try-error"))
-            break
-    }
+    ## FIXME - We should user SOFTWARE\JAGS\version in future
+    regkey <- try(readRegistry("SOFTWARE\\JAGS-1.0.3", 
+                  hive = "HLM", maxdepth = 1), silent = TRUE)
     if (inherits(regkey, "try-error"))
-        stop("Failed to locate a supported JAGS installation")
-    
+        stop("Failed to locate JAGS 1.0.3 installation")
     jags.home <- regkey[["Install_Dir"]]
 
     ## Add jags.home to the windows PATH, if not already present
